@@ -6,6 +6,7 @@
 #include <functional>
 #include <initializer_list>
 #include <memory>
+#include <span>
 
 #include <frc/Timer.h>
 #include <frc/controller/HolonomicDriveController.h>
@@ -21,7 +22,6 @@
 #include <units/length.h>
 #include <units/velocity.h>
 #include <units/voltage.h>
-#include <wpi/span.h>
 
 #include "CommandBase.h"
 #include "CommandHelper.h"
@@ -204,7 +204,7 @@ class MecanumControllerCommand
       std::function<void(units::volt_t, units::volt_t, units::volt_t,
                          units::volt_t)>
           output,
-      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
+      std::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Constructs a new MecanumControllerCommand that when executed will follow
@@ -257,7 +257,7 @@ class MecanumControllerCommand
       std::function<void(units::volt_t, units::volt_t, units::volt_t,
                          units::volt_t)>
           output,
-      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
+      std::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Constructs a new MecanumControllerCommand that when executed will follow
@@ -266,7 +266,7 @@ class MecanumControllerCommand
    *
    * <p>Note: The controllers will *not* set the outputVolts to zero upon
    * completion of the path - this is left to the user, since it is not
-   * appropriate for paths with non-stationary end-states.
+   * appropriate for paths with nonstationary end-states.
    *
    * @param trajectory       The trajectory to follow.
    * @param pose             A function that supplies the robot pose - use one
@@ -304,7 +304,7 @@ class MecanumControllerCommand
    *
    * <p>Note: The controllers will *not* set the outputVolts to zero upon
    * completion of the path - this is left to the user, since it is not
-   * appropriate for paths with non-stationary end-states.
+   * appropriate for paths with nonstationary end-states.
    *
    * <p>Note 2: The final rotation of the robot will be set to the rotation of
    * the final pose in the trajectory. The robot will not follow the rotations
@@ -344,7 +344,7 @@ class MecanumControllerCommand
    *
    * <p>Note: The controllers will *not* set the outputVolts to zero upon
    * completion of the path - this is left to the user, since it is not
-   * appropriate for paths with non-stationary end-states.
+   * appropriate for paths with nonstationary end-states.
    *
    * @param trajectory       The trajectory to follow.
    * @param pose             A function that supplies the robot pose - use one
@@ -373,7 +373,7 @@ class MecanumControllerCommand
                          units::meters_per_second_t,
                          units::meters_per_second_t)>
           output,
-      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
+      std::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Constructs a new MecanumControllerCommand that when executed will follow
@@ -382,7 +382,7 @@ class MecanumControllerCommand
    *
    * <p>Note: The controllers will *not* set the outputVolts to zero upon
    * completion of the path - this is left to the user, since it is not
-   * appropriate for paths with non-stationary end-states.
+   * appropriate for paths with nonstationary end-states.
    *
    * <p>Note2: The final rotation of the robot will be set to the rotation of
    * the final pose in the trajectory. The robot will not follow the rotations
@@ -413,7 +413,7 @@ class MecanumControllerCommand
                          units::meters_per_second_t,
                          units::meters_per_second_t)>
           output,
-      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
+      std::span<std::shared_ptr<Subsystem>> requirements = {});
 
   void Initialize() override;
 
